
Directory listing
-------

**Example:**



    <?php

	/*
	To disable or prevent directory access, add following line in your .htaccess file. If 
	user points the browsers to a directory that does not have an index file, then a
	"403 Forbidden" error will be displayed:

	Add this line of code to your .htaccess file:
	*/

	Options -Indexes 


	?>




	
